#!/usr/bin/gnuplot
# execute instruction line above only works in linux

# usage example (all on one line): gnuplot -e "grafile='graph-file.pdf'; 
#   starttime='2019-07-24T23:30'; stoptime='2019-07-26T23:30'" basic-high-rh.gp

#functions

# saturation vapour pressure at temperature t
svp(t) = 610*exp(t/(t+238.3)*17.2694)

# actual vapour pressure at temperature=t and rh%=rh
vp(t,rh) = svp(t)*rh/100

# rh expected at surface with different temperature than nearby RH sensor
rhsurface(tsensor, rhsensor, tsurface) = 100.0 * mixr(tsensor,rhsensor)/mixr(tsurface,100)


w(t,rh) = log(vp(t,rh)/610.78)
dpt(t,rh) = (w(t,rh)*238.3)/(17.294-w(t,rh))
gm3(t,rh) = vp(t,rh)*2.166/(t + 273.16)

# Mixing ratio g/kg
mixr(t,rh) = (0.62 *10**(-5)*vp(t,rh))*1000 
# Expected RH with no buffer
exprh(tout,rhout,tin) = 100*vp(tout,rhout)/svp(tin)

#end of functions

set output grafile

set encoding utf8
set term pdfcairo enhanced color solid font 'Helvetica,16' size 20cm,16cm
#set lmargin at screen 0.09
set notitle
#set title "Buffered over insulation, 18 {/Symbol \260}C average, 12 hour cycle" font "Helvetica,20"
set xdata time
set timefmt "%Y-%m-%dT%H:%M:%S"
set format x "%d/%H"
set xlabel "Day/Hour" font "Helvetica,18"
#set xtics 3600
#set xrange ["2019-07-24T23:30": "2019-07-26T23:30"]
set xrange [starttime:stoptime]
set yrange [0:100]
set ytics 0,10,100
set mytics 2
set ylabel "Mixing Ratio (g/kg), RH (%)" font "Helvetica,18"
#set y2range [0:47.5]
set y2range [10:60]
set y2label "Temperature ({/Symbol \260}C)" font "Helvetica,18"
set y2tics 10,5,35
#set key below left
set key below right height 1.5
set grid x
set grid mytics
set grid y

#set label 'RH' at graph 0.02,0.80
#set label 'Temperature' at graph 0.02,0.51
#set label 'MR' at graph 0.02,0.12
set style fill transparent solid 0.5 noborder
plot "logdata-all.txt" \
using 1:13 axes x1y2  t 'T room' with lines ls 10  \
,'' using 1:6 axes x1y2  t 'T back plate surface' with lines ls 4  \
,'' using 1:11 axes x1y2  t 'T back RH sensor' with lines ls 2  \
,'' using 1:11:6 axes x1y2 with filledcurves lc "skyblue" notitle \
,'' using 1:2 axes x1y2  t 'T canvas surface' with lines ls 7  \
,'' using 1:17 axes x1y2  t 'T canvas RH sensor' with lines ls 9  \
,'' using 1:17:2 axes x1y2  with filledcurves lc "pink" notitle \
,'' using 1:15 axes x1y2  t 'T beam' with lines ls 13  \
,'' using 1:(rhsurface($11,$12,$6))  t 'RH-c at back plate' with lines ls 15  \
,'' using 1:12  t 'RH near back plate' with lines ls 3  \
,'' using 1:(rhsurface($11,$12,$6)):12  with filledcurves lc "skyblue" notitle \
,'' using 1:(rhsurface($17,$18,$2))  t 'RH-c at canvas' with lines ls 17  \
,'' using 1:18  t 'RH near canvas' with lines ls 8  \
,'' using 1:(rhsurface($17,$18,$2)):18 with filledcurves lc "pink" notitle \
,'' using 1:16 t 'RH beam surface' with lines ls 14  \
,'' using 1:(mixr($13,$14)) t 'MR room' with lines ls 19  \
,'' using 1:(mixr($11,$12)) t 'MR back' with lines ls 16  \
,'' using 1:(mixr($17,$18)) t 'MR canvas' with lines ls 18  \
,'' using 1:(mixr($15,$16)) t 'MR beam' with lines ls 20  \
